GetPreparedStatementFluentBuilder

Struct GetPreparedStatementFluentBuilder 

pub struct GetPreparedStatementFluentBuilder { /* private fields */ }
Fluent builder constructing a request to GetPreparedStatement.

Retrieves the prepared statement with the specified name from the specified workgroup.

Implementations

Source

impl GetPreparedStatementFluentBuilder

pub fn as_input(&self) -> &GetPreparedStatementInputBuilder

Access the GetPreparedStatement as a reference.

pub async fn send( self, ) -> Result<GetPreparedStatementOutput, SdkError<GetPreparedStatementError, HttpResponse>>

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

pub fn customize( self, ) -> CustomizableOperation<GetPreparedStatementOutput, GetPreparedStatementError, Self>

Consumes this builder, creating a customizable operation that can be modified before being sent.

pub fn statement_name(self, input: impl Into<String>) -> Self

The name of the prepared statement to retrieve.

pub fn set_statement_name(self, input: Option<String>) -> Self

The name of the prepared statement to retrieve.

pub fn get_statement_name(&self) -> &Option<String>

The name of the prepared statement to retrieve.

pub fn work_group(self, input: impl Into<String>) -> Self

The workgroup to which the statement to be retrieved belongs.

pub fn set_work_group(self, input: Option<String>) -> Self

The workgroup to which the statement to be retrieved belongs.

pub fn get_work_group(&self) -> &Option<String>

The workgroup to which the statement to be retrieved belongs.