#[non_exhaustive]pub struct GetPreparedStatementInputBuilder { /* private fields */ }Expand description
A builder for GetPreparedStatementInput.
Implementations
Sourceimpl GetPreparedStatementInputBuilder
impl GetPreparedStatementInputBuilder
Sourcepub fn statement_name(self, input: impl Into<String>) -> Self
pub fn statement_name(self, input: impl Into<String>) -> Self
The name of the prepared statement to retrieve.
This field is required.Sourcepub fn set_statement_name(self, input: Option<String>) -> Self
pub fn set_statement_name(self, input: Option<String>) -> Self
The name of the prepared statement to retrieve.
Sourcepub fn get_statement_name(&self) -> &Option<String>
pub fn get_statement_name(&self) -> &Option<String>
The name of the prepared statement to retrieve.
Sourcepub fn work_group(self, input: impl Into<String>) -> Self
pub fn work_group(self, input: impl Into<String>) -> Self
The workgroup to which the statement to be retrieved belongs.
This field is required.Sourcepub fn set_work_group(self, input: Option<String>) -> Self
pub fn set_work_group(self, input: Option<String>) -> Self
The workgroup to which the statement to be retrieved belongs.
Sourcepub fn get_work_group(&self) -> &Option<String>
pub fn get_work_group(&self) -> &Option<String>
The workgroup to which the statement to be retrieved belongs.
Sourcepub fn build(self) -> Result<GetPreparedStatementInput, BuildError>
pub fn build(self) -> Result<GetPreparedStatementInput, BuildError>
Consumes the builder and constructs a GetPreparedStatementInput.
Sourceimpl GetPreparedStatementInputBuilder
impl GetPreparedStatementInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<GetPreparedStatementOutput, SdkError<GetPreparedStatementError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<GetPreparedStatementOutput, SdkError<GetPreparedStatementError, HttpResponse>>
Sends a request with this input using the given client.