#[non_exhaustive]pub struct GetPreparedStatementOutputBuilder { /* private fields */ }Expand description
A builder for GetPreparedStatementOutput.
Implementations
Sourceimpl GetPreparedStatementOutputBuilder
impl GetPreparedStatementOutputBuilder
Sourcepub fn prepared_statement(self, input: PreparedStatement) -> Self
pub fn prepared_statement(self, input: PreparedStatement) -> Self
The name of the prepared statement that was retrieved.
Sourcepub fn set_prepared_statement(self, input: Option<PreparedStatement>) -> Self
pub fn set_prepared_statement(self, input: Option<PreparedStatement>) -> Self
The name of the prepared statement that was retrieved.
Sourcepub fn get_prepared_statement(&self) -> &Option<PreparedStatement>
pub fn get_prepared_statement(&self) -> &Option<PreparedStatement>
The name of the prepared statement that was retrieved.
Sourcepub fn build(self) -> GetPreparedStatementOutput
pub fn build(self) -> GetPreparedStatementOutput
Consumes the builder and constructs a GetPreparedStatementOutput.